
package org.w3c.tidy;

/**
 * Abstract method to provide facilities for viewing each node as
 * it is parsed by tidy and for prepending dynamic content before
 * any bytes read off the standard tidy input stream.
 * 
 * An implementation of this interface registers itself with JTidy
 * by calling {@link NodeHandlerStore#addNewHandler
 * NodeHandlerStore.getInstance().addNewHandler(this);}
 * 
 * @author Ryan Breen (ryan@porivo.com)
 * @since 2/20/02
 */
public interface NodeHandler {

    /**
     * Handle the passed in Node and parent element and return a 
     * modified Node.  Calls to this method are made from Tidy
     * with each call to Node.insertNodeAtEnd, passing in the
     * node and the element to which the node will be appended.
     *
     * @param element The element passed into a call to 
     * Node.insertNodeAtEnd.  This represents the parent element
     * of the node parameter as it is the element to which the
     * node will be appended.
     * @param node New child node parsed from the document and
     * about to be appended to the parent element.
     *
     * @return The child node, potentially modified by the
     * implementing object.
     */
    public org.w3c.dom.Node handleNode(org.w3c.dom.Node element, org.w3c.dom.Node node);

    /**
     * Allows the implementing object to prepend an input stream
     * in front of the current buffer being parsed by Tidy.  Calls
     * to this method are made by StreamInImpl before reading new
     * bytes off of the standard input stream.  This method is
     * useful for extending JTidy to parse dynamic content.
     *
     * @return The first character of dynamic content or -1 none exists.
     */
    public int getDynamicContent() throws java.io.IOException;

}
